import { login, loginUp } from '@/api/newLogin'
import { getToken, setToken, removeToken, setUserId, TokenKey } from '@/utils/auth'
import { resetRouter } from '@/router'
import { Query } from '@/api/dataIntegration'
import { isValue } from "@/utils/validate";
const getDefaultState = () => {
  return {
    token: getToken(),
    name: '',
    avatar: '',
    isLogin: false,
    roles: [],
    UserType: sessionStorage.getItem('UserType') ? sessionStorage.getItem('UserType') : '',
    UserId: sessionStorage.getItem('User_Id') ? sessionStorage.getItem('User_Id') : '',
    userPoewrList: sessionStorage.getItem('userAuthList') ? JSON.parse(sessionStorage.getItem('userAuthList')) : [],
    // userPoewrList: sessionStorage.setItem('userAuthList') ? JSON.parse(sessionStorage.getItem('userAuthList')) : []
    userChecked: !!sessionStorage.getItem('userChecked')
  }
}

const state = getDefaultState()

const mutations = {
  RESET_STATE: state => {
    Object.assign(state, getDefaultState())
  },
  SET_TOKEN: (state, token) => {
    state.token = token
  },
  SET_LOGIN: (state, login) => {
    state.isLogin = login
  },
  SET_NAME: (state, name) => {
    state.name = name
  },
  SET_UserId: (state, UserId) => {
    state.UserId = UserId
  },
  SET_UserType: (state, UserType) => {
    state.UserType = UserType
    sessionStorage.setItem('UserType', UserType)
  },
  SET_ROLES: (state, roles) => {
    state.roles = roles
  },
  SET_AVATAR: (state, avatar) => {
    state.avatar = avatar
  },
  SET_UserPoewrList: (state, arr) => {
    state.userPoewrList = arr
  },
  SET_USER_CHECKED (state, flag) {
    state.userChecked = flag
    if (flag) {
      sessionStorage.setItem('userChecked', 1)
    } else {
      sessionStorage.clearItem('userChecked')
    }
  }
}

const actions = {
  // user login
  login ({ commit }, userInfo) {
    return new Promise((resolve, reject) => {
      login(userInfo)
        .then(response => {
          if (response.code == 0 && isValue(response.returnData)) {
            const { date, token, userid } = response.returnData
            commit('SET_TOKEN', token)
            commit('SET_UserType', 1)
            commit('SET_UserId', userid)
            setToken('userName', userInfo.username)
            setToken(TokenKey, token)
            setUserId(userid)
            setToken('userid', userid)
            resolve(true)
          } else {
            reject(false)
          }
        })
        .catch(error => {
          reject(error)
        })
    })
  },

  // get user info
  getInfo ({ commit, state }) {
    return new Promise((resolve, reject) => {
      Query({
        id: DATACONTENT_ID.loginId,
        dataContent: [getToken('userid')]
      })
        .then(res => {
          if (res.code == 0) {
            const { listValues } = res.returnData
            const datas = listValues
            if (datas && datas.length) {
              const arrs = []
              for (const item of datas) {
                if (item.ident) {
                  arrs.push(item.ident)
                }
              }
              // arrs.push('transit');
              sessionStorage.setItem('userAuthList', JSON.stringify(arrs))
              setTimeout(() => {
                const data = {
                  roles: arrs,
                  introduction: '',
                  avatar: '',
                  name: getToken('userName'),
                  token: state.token
                }

                const { name, avatar, roles } = data

                commit('SET_NAME', name)
                commit('SET_AVATAR', avatar)
                commit('SET_ROLES', roles ? roles : ['admin'])
                commit('SET_UserPoewrList', roles ? roles : ['admin'])
                resolve(data)
              }, 100)
            } else {
              sessionStorage.setItem('userAuthList', [])
              setTimeout(() => {
                const data = {
                  roles: state.userPoewrList,
                  introduction: '',
                  avatar: '',
                  name: getToken('userName'),
                  token: state.token
                }

                const { name, avatar, roles } = data

                commit('SET_NAME', name)
                commit('SET_AVATAR', avatar)
                commit('SET_ROLES', roles ? roles : ['admin'])
                commit('SET_UserPoewrList', roles ? roles : ['admin'])
                resolve(data)
              }, 100)
            }
          } else {
            reject(res.returnData)
          }
        })
        .catch(err => {
          reject(err)
        })
    })
  },

  getMenuInfo ({ commit }) {
    return new Promise((resolve, reject) => {
      Query({
        serviceId: SERVICE_ID.sysMenuId,
        dataContent: {
          user_id: '',
        },
      })
        .then((res) => {
          if (res.code == 0 && isValue(res.returnData)) {
            commit('SET_ROLES', ['admin'])
            resolve(res.returnData)
          } else {
            reject(res.returnData)
          }
        })
        .catch((error) => {
          reject(error)
        })
    })
  },

  // user logout
  logout ({ commit, state }) {
    return new Promise((resolve, reject) => {
      loginUp().then(result => {
        // sessionStorage.removeItem("userName");
        // sessionStorage.removeItem("UserType");
        // sessionStorage.removeItem("User_Id");
        sessionStorage.clear()
        removeToken() // must remove  token  first
        removeToken('codeToken')
        removeToken('systemSet')
        removeToken('userid')
        resetRouter()
        commit('RESET_STATE')
        commit('SET_ROLES', [])
        resolve()
      })

      // logout(state.token).then(() => {
      //   removeToken() // must remove  token  first
      //   resetRouter()
      //   commit('RESET_STATE')
      //   resolve()
      // }).catch(error => {
      //   reject(error)
      // })
    })
  },

  // remove token
  resetToken ({ commit }) {
    return new Promise(resolve => {
      removeToken() // must remove  token  first
      commit('RESET_STATE')
      commit('SET_ROLES', [])
      resolve()
    })
  },

  setPowerList ({ commit }, arr) {
    commit('SET_UserPoewrList', arr)
  },

  setPowerToken ({ commit }, token) {
    commit('SET_TOKEN', token)
  },

  setPowerName ({ commit }, name) {
    commit('SET_NAME', name)
  },

  setIsLogin ({ commit }, login) {
    commit('SET_LOGIN', login)
  },

  setUserChecked ({ commit }, flag) {
    commit('SET_USER_CHECKED', flag)
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}
